Aio Fluid

Async utilities for backend python services

[![PyPI version](https://badge.fury.io/py/aio-fluid.svg)](https://badge.fury.io/py/aio-fluid)
[![Python versions](https://img.shields.io/pypi/pyversions/aio-fluid.svg)](https://pypi.org/project/aio-fluid)
[![build](https://github.com/quantmind/fluid/workflows/build/badge.svg)](https://github.com/quantmind/aio-fluid/actions?query=workflow%3Abuild)
[![codecov](https://codecov.io/gh/quantmind/aio-fluid/graph/badge.svg?token=81oWUoyEVp)](https://codecov.io/gh/quantmind/aio-fluid)

**Documentation**: [https://quantmind.github.io/aio-fluid](https://quantmind.github.io/aio-fluid)

**Source Code**: [https://github.com/quantmind/aio-fluid](https://github.com/quantmind/aio-fluid)


## Installation

This is a simple python package you can install via pip:

```
pip install aio-fluid
```

To install all the dependencies, you can use the `full` extra:

```
pip install aio-fluid[full]
```
this includes the following extra dependencies:

- `cli` for the command line interface
- `db` for database support
- `http` for http client support
- `log` for JSON logging support


## Development

You can run the examples via

```
poetry run python -m examples.main
```
